==> carbon-component-mapper-3.11.0.tgz: package/esm/tabs/tabs.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import createUseStyles from "react-jss/dist/react-jss.esm.js";
import CarbonTabs from "carbon-components-react/es/components/Tabs/Tabs.js";
import Tab from "carbon-components-react/es/components/Tab/Tab.js";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
var useStyles = createUseStyles({
  tab: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});

var Tabs = function Tabs(_ref) {
  var fields = _ref.fields,
      component = _ref.component,
      name = _ref.name,
      TabWrapperProps = _ref.TabWrapperProps,
      props = _objectWithoutProperties(_ref, ["fields", "component", "name", "TabWrapperProps"]);

  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      tab = _useStyles.tab;

  return /*#__PURE__*/React.createElement(CarbonTabs, props, fields.map(function (_ref2) {
    var fields = _ref2.fields,
        name = _ref2.name,
        label = _ref2.label,
        title = _ref2.title,
        rest = _objectWithoutProperties(_ref2, ["fields", "name", "label", "title"]);

    return /*#__PURE__*/React.createElement(Tab, _extends({}, rest, {
      id: name,
      key: name,
      label: label || title
    }), /*#__PURE__*/React.createElement("div", _extends({}, TabWrapperProps, {
      className: clsx(tab, TabWrapperProps.className)
    }), formOptions.renderForm(fields, formOptions)));
  }));
};

Tabs.propTypes = {
  TabWrapperProps: PropTypes.object,
  component: PropTypes.string,
  name: PropTypes.string,
  fields: PropTypes.arrayOf(PropTypes.shape({
    name: PropTypes.string,
    fields: PropTypes.array,
    title: PropTypes.node,
    label: PropTypes.node
  }))
};
Tabs.defaultProps = {
  TabWrapperProps: {}
};
export default Tabs;

==> carbon-component-mapper-3.11.4.tgz: package/esm/tabs/tabs.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import CarbonTabs from "carbon-components-react/es/components/Tabs/Tabs.js";
import Tab from "carbon-components-react/es/components/Tab/Tab.js";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
var useStyles = createUseStyles({
  tab: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});

var Tabs = function Tabs(_ref) {
  var fields = _ref.fields,
      component = _ref.component,
      name = _ref.name,
      TabWrapperProps = _ref.TabWrapperProps,
      props = _objectWithoutProperties(_ref, ["fields", "component", "name", "TabWrapperProps"]);

  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      tab = _useStyles.tab;

  return /*#__PURE__*/React.createElement(CarbonTabs, props, fields.map(function (_ref2) {
    var fields = _ref2.fields,
        name = _ref2.name,
        label = _ref2.label,
        title = _ref2.title,
        rest = _objectWithoutProperties(_ref2, ["fields", "name", "label", "title"]);

    return /*#__PURE__*/React.createElement(Tab, _extends({}, rest, {
      id: name,
      key: name,
      label: label || title
    }), /*#__PURE__*/React.createElement("div", _extends({}, TabWrapperProps, {
      className: clsx(tab, TabWrapperProps.className)
    }), formOptions.renderForm(fields, formOptions)));
  }));
};

Tabs.propTypes = {
  TabWrapperProps: PropTypes.object,
  component: PropTypes.string,
  name: PropTypes.string,
  fields: PropTypes.arrayOf(PropTypes.shape({
    name: PropTypes.string,
    fields: PropTypes.array,
    title: PropTypes.node,
    label: PropTypes.node
  }))
};
Tabs.defaultProps = {
  TabWrapperProps: {}
};
export default Tabs;
